Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/owncloud/client.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/folder.cpp')
-rw-r--r--src/gui/folder.cpp10
1 files changed, 8 insertions, 2 deletions
diff --git a/src/gui/folder.cpp b/src/gui/folder.cpp
index 2bde6516e..f10641b1a 100644
--- a/src/gui/folder.cpp
+++ b/src/gui/folder.cpp
@@ -590,8 +590,9 @@ void Folder::downloadVirtualFile(const QString &_relativepath)
if (record._type == ItemTypeVirtualFile) {
record._type = ItemTypeVirtualFileDownload;
_journal.setFileRecord(record);
- // Make sure we go over that file during the discovery
- _journal.avoidReadFromDbOnNextSync(relativepath);
+ // Make sure we go over that file during the discovery even if
+ // no actual remote discovery would be necessary
+ _journal.schedulePathForRemoteDiscovery(relativepath);
} else if (record._type == ItemTypeDirectory || relativepath.isEmpty()) {
_journal.markVirtualFileForDownloadRecursively(relativepath);
} else {
@@ -1127,6 +1128,11 @@ void Folder::slotNextSyncFullLocalDiscovery()
_timeSinceLastFullLocalDiscovery.invalidate();
}
+void Folder::schedulePathForLocalDiscovery(const QString &relativePath)
+{
+ _localDiscoveryTracker->addTouchedPath(relativePath.toUtf8());
+}
+
void Folder::slotFolderConflicts(const QString &folder, const QStringList &conflictPaths)
{
if (folder != _definition.alias)